@@ -14,9 +14,10 @@ BEGIN {
 }
 
 require DynaLoader;
-our @ISA = qw( DynaLoader C::Blocks::libloader );
+our @ISA = qw( DynaLoader );
+*import = \&C::Blocks::libloader::import;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 bootstrap C::Blocks::PerlAPI $VERSION;
 $VERSION = eval $VERSION;
 
